A Python library for maintaining and managing DANDI metadata schemata. The
library helps create and validate DANDI schema-compliant metadata for Dandisets
and assets.

To use: `pip install dandischema`

More documentation coming soon.
